/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */

/*! \file variable.h
	\brief Zarządzanie zmiennymi
*/

#ifndef __LW_VARIABLE_H
#define __LW_VARIABLE_H

#include "value.h"

/*! \class LWVariable
	\brief Zarządzanie zmiennymi

	Klasa zarządzająca zmiennymi używanymi jako argumenty poleceń
*/
class LWVariable: public LWValue {
public:
LWVariable ();
LWVariable (LWPixmap *pixmap);
LWVariable (const LWValue *value);
virtual LWValue *getIndex (guint n);
gboolean isVariable ();
};

#endif
