( cd usr/lib ; rm -rf liblanguage.so.0 )
( cd usr/lib ; ln -sf liblanguage.so.0.0.0 liblanguage.so.0 )
( cd usr/lib ; rm -rf liblw.so.0 )
( cd usr/lib ; ln -sf liblw.so.0.0.0 liblw.so.0 )
( cd usr/lib ; rm -rf liblw.so )
( cd usr/lib ; ln -sf liblw.so.0.0.0 liblw.so )
( cd usr/lib ; rm -rf liblanguage.so )
( cd usr/lib ; ln -sf liblanguage.so.0.0.0 liblanguage.so )
