/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */

#include "include/command.h"
 
class LWInterpreter {
LWProgram *program;
LWProgramData *program_data;
LWContext context;
GNode *lastip;
GNode *resume_point;
GSList *list;
GSList *list_entry;
void buildList();
void finish();
	
public:
LWInterpreter (LWProgram *a_program, LWProgramData *a_program_data);
~LWInterpreter ();
void execute ();
gboolean resume ();
void stop();
gboolean isRunning();
LWContext *getContext();
};
