/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */

/*! \file pixmapset.h 
	\brief Obsługa zbioru ikon
*/

#ifndef __LW_PIXMAPSSET_H
#define __LW_PIXMAPSSET_H

#include <libxml/tree.h>

#include "pixmap.h"

/*! \class LWPixmapSet
	\brief Klasa reprezentująca zbiór ikon

	Klasa zarządzająca zbiorem ikon
*/

class LWPixmapSet {
private:
GData *datalist;
public:
LWPixmapSet (void);
~LWPixmapSet ();
void restoreFromXML (xmlNode *node);
void addPixmap (LWPixmap *pixmap);
LWPixmap *getPixmap (const gchar *name);
};

#endif
