/* (C) Marcin Kwadrans <quarter@users.sourceforge.net> */

/*! \file pixmap.h 
	\brief Obsługa ikon
*/

#ifndef __LW_PIXMAP_H
#define __LW_PIXMAP_H

#include <libxml/tree.h>

#define ICON_XSIZE 40
#define ICON_YSIZE 40

/*! \class LWPixmap
	\brief Klasa reprezentująca ikonę

	Klasa zarządzająca pojedynczą ikoną.
*/
class LWPixmap {
private:
gchar *name;
GdkPixbuf *pixbuf;
public:	
LWPixmap ();
~LWPixmap ();
LWPixmap (const LWPixmap *pixmap);
void restoreFromXML (xmlNode *node);
GdkPixbuf *getPixbuf ();
gchar *getName ();
};
#endif
